@@ -17,15 +17,14 @@ from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
 
-import json
 
 from oslo_log import log as logging
+from oslo_serialization import jsonutils as json
 
 from congress.api import api_utils
 from congress.api import base
 from congress.api import error_codes
 from congress.api import webservice
-from congress.dse2 import dse_node
 from congress import exception
 
 LOG = logging.getLogger(__name__)
@@ -38,12 +37,11 @@ class DatasourceModel(base.APIModel):
     def get_items(self, params, context=None):
         """Get items in model.
 
-        Args:
-            params: A dict-like object containing parameters
-                    from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: params: A dict-like object containing parameters
+            from the request query string and body.
+        :param: context: Key-values providing frame of reference of request
 
-        Returns: A dict containing at least a 'results' key whose value is
+        :returns: A dict containing at least a 'results' key whose value is
                  a list of items in the model.  Additional keys set in the
                  dict will also be rendered for the user.
         """
@@ -58,25 +56,32 @@ class DatasourceModel(base.APIModel):
 
         return {"results": results}
 
+    def get_item(self, id_, params, context=None):
+        """Get datasource corresponding to id\_ in model."""
+        try:
+            datasource = self.bus.get_datasource(id_)
+            return datasource
+        except exception.DatasourceNotFound as e:
+            LOG.exception("Datasource '%s' not found", id_)
+            raise webservice.DataModelException(e.code, str(e),
+                                                http_status_code=e.code)
+
     # Note(thread-safety): blocking function
     def add_item(self, item, params, id_=None, context=None):
         """Add item to model.
 
-         Args:
-             item: The item to add to the model
-             id_: The ID of the item, or None if an ID should be generated
-             context: Key-values providing frame of reference of request
+         :param: item: The item to add to the model
+         :param: id\_: The ID of the item, or None if an ID should be generated
+         :param: context: Key-values providing frame of reference of request
 
-         Returns:
-              Tuple of (ID, newly_created_item)
+         :returns:  Tuple of (ID, newly_created_item)
 
-         Raises:
-             KeyError: ID already exists.
+         :raises  KeyError: ID already exists.
          """
         obj = None
         try:
             # Note(thread-safety): blocking call
-            obj = self.invoke_rpc(dse_node.DS_MANAGER_SERVICE_ID,
+            obj = self.invoke_rpc(base.DS_MANAGER_SERVICE_ID,
                                   'add_datasource',
                                   {'items': item},
                                   timeout=self.dse_long_timeout)
@@ -86,12 +91,8 @@ class DatasourceModel(base.APIModel):
                 exception.DriverNotFound,
                 exception.DatasourceCreationError) as e:
             LOG.exception(_("Datasource creation failed."))
-            if obj:
-                # Do cleanup
-                # Note(thread-safety): blocking call
-                self.delete_datasource(obj)
-            raise webservice.DataModelException(e.code, str(e),
-                                                http_status_code=e.code)
+            raise webservice.DataModelException(
+                e.code, webservice.original_msg(e), http_status_code=e.code)
 
         return (obj['id'], obj)
 
@@ -108,7 +109,7 @@ class DatasourceModel(base.APIModel):
             #  delete a different datasource
             #  Fix: check UUID of datasource before operating.
             #  Abort if mismatch
-            self.invoke_rpc(dse_node.DS_MANAGER_SERVICE_ID,
+            self.invoke_rpc(base.DS_MANAGER_SERVICE_ID,
                             'delete_datasource',
                             {'datasource': datasource},
                             timeout=self.dse_long_timeout)
@@ -145,7 +146,7 @@ class DatasourceModel(base.APIModel):
             # TODO(ekcs): perhaps keep execution synchronous when explicitly
             #   called via API
             # Note(thread-safety): blocking call
-            self.invoke_rpc(base.ENGINE_SERVICE, 'execute_action', args)
+            self.invoke_rpc(base.ENGINE_SERVICE_ID, 'execute_action', args)
         except exception.PolicyException as e:
             (num, desc) = error_codes.get('execute_error')
             raise webservice.DataModelException(num, desc + "::" + str(e))
