@@ -137,7 +137,7 @@ class APIRouterV1(object):
         rows_path = "%s/rows" % table_path
         row_collection_handler = webservice.CollectionHandler(
             rows_path,
-            table_rows, allow_update=True)
+            table_rows, allow_replace=True)
         resource_mgr.register_handler(row_collection_handler)
         row_path = "%s/(?P<row_id>[^/]+)" % rows_path
         row_element_handler = webservice.ElementHandler(row_path, table_rows)
