@@ -22,11 +22,12 @@ try:
     import http.client as httplib
 except ImportError:
     import httplib
-import json
 import re
 
 from oslo_config import cfg
+from oslo_db import exception as db_exc
 from oslo_log import log as logging
+from oslo_serialization import jsonutils as json
 from oslo_utils import uuidutils
 import six
 import webob
@@ -106,9 +107,9 @@ class DataModelException(Exception):
     def create(cls, error):
         """Generate a DataModelException from an existing CongressException.
 
-        :param error has a 'name' field corresponding to an error_codes
-        error-name.  It may also have a 'data' field.
-        Returns a DataModelException properly populated.
+        :param: error: has a 'name' field corresponding to an error_codes
+            error-name.  It may also have a 'data' field.
+        :returns: a DataModelException properly populated.
         """
         name = getattr(error, "name", None)
         if name:
@@ -183,11 +184,9 @@ class AbstractApiHandler(object):
     def handle_request(self, request):
         """Handle a REST request.
 
-        Args:
-           request: A webob request object.
+        :param: request: A webob request object.
 
-        Returns:
-            A webob response object.
+        :returns: A webob response object.
         """
         return NOT_SUPPORTED_RESPONSE
 
@@ -197,10 +196,10 @@ class ElementHandler(AbstractApiHandler):
 
     REST elements represent individual entities in the data model, and often
     support the following operations:
-        - Read a representation of the element
-        - Update (replace) the entire element with a new version
-        - Update (patch) parts of the element with new values
-        - Delete the element
+    - Read a representation of the element
+    - Update (replace) the entire element with a new version
+    - Update (patch) parts of the element with new values
+    - Delete the element
 
     Elements may also exhibit 'controller' semantics for RPC-style method
     invocation, however this is not currently supported.
@@ -211,18 +210,17 @@ class ElementHandler(AbstractApiHandler):
                  allow_replace=True, allow_update=True, allow_delete=True):
         """Initialize an element handler.
 
-        Args:
-            path_regex: A regular expression that matches the full path
+        :param: path_regex: A regular expression that matches the full path
                 to the element.  If multiple handlers match a request path,
                 the handler with the highest registration search_index wins.
-            model: A resource data model instance
-            collection_handler: The collection handler this element
+        :param: model: A resource data model instance
+        :param: collection_handler: The collection handler this element
                 is a member of or None if the element is not a member of a
                 collection.  (Used for named creation of elements)
-            allow_read: True if element supports read
-            allow_replace: True if element supports replace
-            allow_update: True if element supports update
-            allow_delete: True if element supports delete
+        :param: allow_read: True if element supports read
+        :param: allow_replace: True if element supports replace
+        :param: allow_update: True if element supports update
+        :param: allow_delete: True if element supports delete
 
         """
         super(ElementHandler, self).__init__(path_regex)
@@ -243,23 +241,25 @@ class ElementHandler(AbstractApiHandler):
     def handle_request(self, request):
         """Handle a REST request.
 
-        Args:
-           request: A webob request object.
+        :param: request: A webob request object.
 
-        Returns:
-            A webob response object.
+        :returns: A webob response object.
         """
-        if request.method == 'GET' and self.allow_read:
-            return self.read(request)
-        elif request.method == 'POST' and self.allow_actions:
-            return self.action(request)
-        elif request.method == 'PUT' and self.allow_replace:
-            return self.replace(request)
-        elif request.method == 'PATCH' and self.allow_update:
-            return self.update(request)
-        elif request.method == 'DELETE' and self.allow_delete:
-            return self.delete(request)
-        return NOT_SUPPORTED_RESPONSE
+        try:
+            if request.method == 'GET' and self.allow_read:
+                return self.read(request)
+            elif request.method == 'POST' and self.allow_actions:
+                return self.action(request)
+            elif request.method == 'PUT' and self.allow_replace:
+                return self.replace(request)
+            elif request.method == 'PATCH' and self.allow_update:
+                return self.update(request)
+            elif request.method == 'DELETE' and self.allow_delete:
+                return self.delete(request)
+            return NOT_SUPPORTED_RESPONSE
+        except db_exc.DBError:
+            LOG.exception('Database backend experienced an unknown error.')
+            raise exception.DatabaseError
 
     def read(self, request):
         if not hasattr(self.model, 'get_item'):
@@ -308,8 +308,8 @@ class ElementHandler(AbstractApiHandler):
         id_ = self._get_element_id(request)
         try:
             item = self._parse_json_body(request)
-            self.model.update_item(id_, item, request.params,
-                                   context=self._get_context(request))
+            self.model.replace_item(id_, item, request.params,
+                                    context=self._get_context(request))
         except KeyError as e:
             if (self.collection_handler and
                     getattr(self.collection_handler, 'allow_named_create',
@@ -335,7 +335,7 @@ class ElementHandler(AbstractApiHandler):
 
         updates = self._parse_json_body(request)
         item.update(updates)
-        self.model.update_item(id_, item, request.params, context=context)
+        self.model.replace_item(id_, item, request.params, context=context)
         return webob.Response(body="%s\n" % json.dumps(item),
                               status=httplib.OK,
                               content_type='application/json',
@@ -364,22 +364,22 @@ class CollectionHandler(AbstractApiHandler):
 
     REST collections represent collections of entities in the data model, and
     often support the following operations:
-        - List elements in the collection
-        - Create new element in the collection
+    - List elements in the collection
+    - Create new element in the collection
 
     The following less-common collection operations are NOT SUPPORTED:
-        - Replace all elements in the collection
-        - Delete all elements in the collection
+    - Replace all elements in the collection
+    - Delete all elements in the collection
     """
 
     def __init__(self, path_regex, model,
                  allow_named_create=True, allow_list=True, allow_create=True,
-                 allow_update=False):
+                 allow_replace=False):
         """Initialize a collection handler.
 
-        Args:
-            path_regex: A regular expression matching the collection base path.
-            model: A resource data model instance
+        :param: path_regex: A regular expression matching the collection base
+            path.
+        :param: model: A resource data model instance
             allow_named_create: True if caller can specify ID of new items.
             allow_list: True if collection supports listing elements.
             allow_create: True if collection supports creating elements.
@@ -389,16 +389,14 @@ class CollectionHandler(AbstractApiHandler):
         self.allow_named_create = allow_named_create
         self.allow_list = allow_list
         self.allow_create = allow_create
-        self.allow_update = allow_update
+        self.allow_replace = allow_replace
 
     def handle_request(self, request):
         """Handle a REST request.
 
-        Args:
-           request: A webob request object.
+        :param: request: A webob request object.
 
-        Returns:
-            A webob response object.
+        :returns: A webob response object.
         """
         # NOTE(arosen): only do policy.json if keystone is used for now.
         if cfg.CONF.auth_strategy == "keystone":
@@ -426,8 +424,8 @@ class CollectionHandler(AbstractApiHandler):
             return self.list_members(request)
         elif request.method == 'POST' and self.allow_create:
             return self.create_member(request)
-        elif request.method == 'PUT' and self.allow_update:
-            return self.update_members(request)
+        elif request.method == 'PUT' and self.allow_replace:
+            return self.replace_members(request)
         return NOT_SUPPORTED_RESPONSE
 
     def _get_action_type(self, method):
@@ -480,13 +478,13 @@ class CollectionHandler(AbstractApiHandler):
                               location="%s/%s" % (request.path, id_),
                               charset='UTF-8')
 
-    def update_members(self, request):
-        if not hasattr(self.model, 'update_items'):
+    def replace_members(self, request):
+        if not hasattr(self.model, 'replace_items'):
             return NOT_SUPPORTED_RESPONSE
         items = self._parse_json_body(request)
         context = self._get_context(request)
         try:
-            self.model.update_items(items, request.params, context)
+            self.model.replace_items(items, request.params, context)
         except KeyError as e:
             LOG.exception("Error occurred")
             return error_response(httplib.BAD_REQUEST, httplib.BAD_REQUEST,
@@ -513,12 +511,11 @@ class SimpleDataModel(object):
     def get_items(self, params, context=None):
         """Get items in model.
 
-        Args:
-            params: A dict-like object containing parameters
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: context: Key-values providing frame of reference of request
 
-        Returns: A dict containing at least a 'results' key whose value is
+        :returns: A dict containing at least a 'results' key whose value is
                  a list of items in the model.  Additional keys set in the
                  dict will also be rendered for the user.
         """
@@ -529,19 +526,16 @@ class SimpleDataModel(object):
     def add_item(self, item, params, id_=None, context=None):
         """Add item to model.
 
-        Args:
-            item: The item to add to the model
-            params: A dict-like object containing parameters
+        :param: item: The item to add to the model
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            id_: The ID of the item, or None if an ID should be generated
-            context: Key-values providing frame of reference of request
+        :param: The ID of the item, or None if an ID should be generated
+        :param: context: Key-values providing frame of reference of request
 
-        Returns:
-             Tuple of (ID, newly_created_item)
+        :returns: Tuple of (ID, newly_created_item)
 
-        Raises:
-            KeyError: ID already exists.
-            DataModelException: Addition cannot be performed.
+        :raises KeyError: ID already exists.
+        :raises DataModelException: Addition cannot be performed.
         """
         cstr = self._context_str(context)
         if id_ is None:
@@ -553,36 +547,31 @@ class SimpleDataModel(object):
         return (id_, item)
 
     def get_item(self, id_, params, context=None):
-        """Retrieve item with id id_ from model.
+        """Retrieve item with id id\_ from model.
 
-        Args:
-            id_: The ID of the item to retrieve
-            params: A dict-like object containing parameters
+        :param: id\_: The ID of the item to retrieve
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: context: Key-values providing frame of reference of request
 
-        Returns:
-             The matching item or None if item with id_ does not exist.
+        :returns: The matching item or None if item with id\_ does not exist.
         """
         cstr = self._context_str(context)
         return self.items.setdefault(cstr, {}).get(id_)
 
     def update_item(self, id_, item, params, context=None):
-        """Update item with id_ with new data.
+        """Update item with id\_ with new data.
 
-        Args:
-            id_: The ID of the item to be updated
+        :param: id\_: The ID of the item to be updated
             item: The new item
-            params: A dict-like object containing parameters
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: context: Key-values providing frame of reference of request
 
-        Returns:
-             The updated item.
+        :returns: The updated item.
 
-        Raises:
-            KeyError: Item with specified id_ not present.
-            DataModelException: Update cannot be performed.
+        :raises KeyError: Item with specified id\_ not present.
+        :raises DataModelException: Update cannot be performed.
         """
         cstr = self._context_str(context)
         if id_ not in self.items.setdefault(cstr, {}):
@@ -591,34 +580,50 @@ class SimpleDataModel(object):
         self.items.setdefault(cstr, {})[id_] = item
         return item
 
+    def replace_item(self, id_, item, params, context=None):
+        """Replace item with id\_ with new data.
+
+        :param: id\_: The ID of the item to be replaced
+            item: The new item
+        :param: params: A dict-like object containing parameters
+                    from the request query string and body.
+        :param: context: Key-values providing frame of reference of request
+
+        :returns: The new item after replacement.
+
+        :raises KeyError: Item with specified id\_ not present.
+        :raises DataModelException: Replacement cannot be performed.
+        """
+        cstr = self._context_str(context)
+        if id_ not in self.items.setdefault(cstr, {}):
+            raise KeyError("Cannot replace item with ID '%s': "
+                           "ID does not exist" % id_)
+        self.items.setdefault(cstr, {})[id_] = item
+        return item
+
     def delete_item(self, id_, params, context=None):
         """Remove item from model.
 
-        Args:
-            id_: The ID of the item to be removed
-            params: A dict-like object containing parameters
+        :param: id\_: The ID of the item to be removed
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: context: Key-values providing frame of reference of request
 
-        Returns:
-             The removed item.
+        :returns: The removed item.
 
-        Raises:
-            KeyError: Item with specified id_ not present.
+        :raises KeyError: Item with specified id\_ not present.
         """
         cstr = self._context_str(context)
         ret = self.items.setdefault(cstr, {})[id_]
         del self.items[cstr][id_]
         return ret
 
-    def update_items(self, items, params, context=None):
-        """Update items in the model.
+    def replace_items(self, items, params, context=None):
+        """Replace items in the model.
 
-        Args:
-            items: A dict-like object containing new data
-            params: A dict-like object containing parameters
-            context: Key-values providing frame of reference of request
-        Returns:
-            None.
+        :param: items: A dict-like object containing new data
+        :param: params: A dict-like object containing parameters
+        :param: context: Key-values providing frame of reference of request
+        :returns: None
         """
         self.items = items
