@@ -1221,7 +1221,7 @@ class PushedDataSourceDriver(DataSourceDriver):
             self.state[table['tablename']] = table['tabledata']
 
     # Note (thread-safety): blocking function
-    def update_entire_data(self, table_id, objs):
+    def replace_entire_table_data(self, table_id, objs):
         LOG.info('update %s table in %s datasource', table_id, self.name)
         translator = self.get_translator(table_id)
         tablename = translator['table-name']
@@ -1250,9 +1250,9 @@ class PushedDataSourceDriverEndpoints(data_service.DataServiceEndPoints):
         super(PushedDataSourceDriverEndpoints, self).__init__(service)
 
     # Note (thread-safety): blocking function
-    def update_entire_data(self, context, table_id, source_id, objs):
+    def replace_entire_table_data(self, context, table_id, source_id, objs):
         # Note (thread-safety): blocking call
-        return self.service.update_entire_data(table_id, objs)
+        return self.service.replace_entire_table_data(table_id, objs)
 
 
 class PollingDataSourceDriver(DataSourceDriver):
@@ -1432,7 +1432,7 @@ class PollingDataSourceDriver(DataSourceDriver):
         Triggers polling every *poll_time* seconds or after *request_refresh*
         is called.
 
-        :param poll_time: is the amount of time (in seconds) to wait between
+        :param: poll_time: is the amount of time (in seconds) to wait between
         polling rounds.
         """
         LOG.debug("start to poll from datasource %s", self.name)
@@ -1595,8 +1595,8 @@ class ExecutionDriver(object):
         """This method must be implemented by each driver.
 
         Action can be a service API or a user-defined function
-        :param action: a user-defined function or a service API call
-        :param action_args: in format of
+        :param: action: a user-defined function or a service API call
+        :param: action_args: in format of
            {'positional': ['arg1', 'arg2'],
             'named': {'key1': 'value1', 'key2': 'value2'}}
         """
@@ -1608,7 +1608,7 @@ class ExecutionDriver(object):
     def _convert_args(self, positional_args):
         """Convert positional args to optional/named args.
 
-        :param <list> positional_args: items are assumed being
+        :param: <list> positional_args: items are assumed being
         ordered as ['key1', 'value1', 'key2', 'value2',].
         :return <dict>: {'key1': 'value1', 'key2': 'value2'}
         """
