@@ -77,7 +77,7 @@ class GlanceV2Driver(datasource_driver.PollingDataSourceDriver,
              {'fieldname': 'file',
               'desc': 'URL for the virtual machine image file',
               'translator': value_trans},
-             {'fieldname': 'kernel_id', 'desc': 'kernal id',
+             {'fieldname': 'kernel_id', 'desc': 'kernel id',
               'translator': value_trans},
              {'fieldname': 'ramdisk_id', 'desc': 'ramdisk id',
               'translator': value_trans},
