@@ -13,28 +13,40 @@
 #    under the License.
 #
 
+"""Schema version history
+
+version: 2.1
+date: 2017-10-01
+changes:
+ - Added the tags table for server tags information.
+
+version: 2.0
+Initial schema version.
+"""
+
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
 import novaclient.client
 from oslo_log import log as logging
 import six
 
+from congress.datasources import constants
 from congress.datasources import datasource_driver
 from congress.datasources import datasource_utils as ds_utils
 
 LOG = logging.getLogger(__name__)
 
 
-def d6service(name, keys, inbox, datapath, args):
-    """This method is called by d6cage to create a dataservice instance."""
-    return NovaDriver(name, keys, inbox, datapath, args)
-
-
-class NovaDriver(datasource_driver.DataSourceDriver,
+class NovaDriver(datasource_driver.PollingDataSourceDriver,
                  datasource_driver.ExecutionDriver):
     SERVERS = "servers"
     FLAVORS = "flavors"
     HOSTS = "hosts"
-    FLOATING_IPS = "floating_IPs"
     SERVICES = 'services'
+    AVAILABILITY_ZONES = "availability_zones"
+    TAGS = "tags"
 
     # This is the most common per-value translator, so define it once here.
     value_trans = {'translation-type': 'VALUE'}
@@ -52,85 +64,133 @@ class NovaDriver(datasource_driver.DataSourceDriver,
         'table-name': SERVERS,
         'selector-type': 'DOT_SELECTOR',
         'field-translators':
-            ({'fieldname': 'id', 'translator': value_trans},
-             {'fieldname': 'name', 'translator': value_trans},
+            ({'fieldname': 'id', 'desc': 'The UUID for the server',
+              'translator': value_trans},
+             {'fieldname': 'name', 'desc': 'Name of the server',
+              'translator': value_trans},
              {'fieldname': 'hostId', 'col': 'host_id',
+              'desc': 'The UUID for the host', 'translator': value_trans},
+             {'fieldname': 'status', 'desc': 'The server status',
+              'translator': value_trans},
+             {'fieldname': 'tenant_id', 'desc': 'The tenant ID',
+              'translator': value_trans},
+             {'fieldname': 'user_id',
+              'desc': 'The user ID of the user who owns the server',
               'translator': value_trans},
-             {'fieldname': 'status', 'translator': value_trans},
-             {'fieldname': 'tenant_id', 'translator': value_trans},
-             {'fieldname': 'user_id', 'translator': value_trans},
              {'fieldname': 'image', 'col': 'image_id',
+              'desc': 'Name or ID of image',
               'translator': {'translation-type': 'VALUE',
                              'extract-fn': safe_id}},
              {'fieldname': 'flavor', 'col': 'flavor_id',
+              'desc': 'ID of the flavor',
               'translator': {'translation-type': 'VALUE',
-                             'extract-fn': safe_id}})}
+                             'extract-fn': safe_id}},
+             {'fieldname': 'OS-EXT-AZ:availability_zone', 'col': 'zone',
+              'desc': 'The availability zone of host',
+              'translator': value_trans},
+             {'fieldname': 'OS-EXT-SRV-ATTR:hypervisor_hostname',
+              'desc': ('The hostname of hypervisor where the server is '
+                       'running'),
+              'col': 'host_name', 'translator': value_trans},
+             {'fieldname': 'tags',
+              'translator': {'translation-type': 'LIST',
+                             'table-name': TAGS,
+                             'parent-key': 'id',
+                             'parent-col-name': 'server_id',
+                             'parent-key-desc': 'UUID of server',
+                             'val-col': 'tag',
+                             'val-col-desc': 'server tag string',
+                             'translator': value_trans}})}
 
     flavors_translator = {
         'translation-type': 'HDICT',
         'table-name': FLAVORS,
         'selector-type': 'DOT_SELECTOR',
         'field-translators':
-            ({'fieldname': 'id', 'translator': value_trans},
-             {'fieldname': 'name', 'translator': value_trans},
-             {'fieldname': 'vcpus', 'translator': value_trans},
-             {'fieldname': 'ram', 'translator': value_trans},
-             {'fieldname': 'disk', 'translator': value_trans},
-             {'fieldname': 'ephemeral', 'translator': value_trans},
-             {'fieldname': 'rxtx_factor', 'translator': value_trans})}
+            ({'fieldname': 'id', 'desc': 'ID of the flavor',
+              'translator': value_trans},
+             {'fieldname': 'name', 'desc': 'Name of the flavor',
+              'translator': value_trans},
+             {'fieldname': 'vcpus', 'desc': 'Number of vcpus',
+              'translator': value_trans},
+             {'fieldname': 'ram', 'desc': 'Memory size in MB',
+              'translator': value_trans},
+             {'fieldname': 'disk', 'desc': 'Disk size in GB',
+              'translator': value_trans},
+             {'fieldname': 'ephemeral', 'desc': 'Ephemeral space size in GB',
+              'translator': value_trans},
+             {'fieldname': 'rxtx_factor', 'desc': 'RX/TX factor',
+              'translator': value_trans})}
 
     hosts_translator = {
         'translation-type': 'HDICT',
         'table-name': HOSTS,
         'selector-type': 'DOT_SELECTOR',
         'field-translators':
-            ({'fieldname': 'host_name', 'translator': value_trans},
-             {'fieldname': 'service', 'translator': value_trans},
-             {'fieldname': 'zone', 'translator': value_trans})}
-
-    floating_ips_translator = {
-        'translation-type': 'HDICT',
-        'table-name': FLOATING_IPS,
-        'selector-type': 'DOT_SELECTOR',
-        'field-translators':
-            ({'fieldname': 'fixed_ip', 'translator': value_trans},
-             {'fieldname': 'id', 'translator': value_trans},
-             {'fieldname': 'ip', 'translator': value_trans},
-             {'fieldname': 'instance_id', 'col': 'host_id',
+            ({'fieldname': 'host_name', 'desc': 'Name of host',
               'translator': value_trans},
-             {'fieldname': 'pool', 'translator': value_trans})}
+             {'fieldname': 'service', 'desc': 'Enabled service',
+              'translator': value_trans},
+             {'fieldname': 'zone', 'desc': 'The availability zone of host',
+              'translator': value_trans})}
 
     services_translator = {
         'translation-type': 'HDICT',
         'table-name': SERVICES,
         'selector-type': 'DOT_SELECTOR',
         'field-translators':
-            ({'fieldname': 'id', 'col': 'service_id',
+            ({'fieldname': 'id', 'col': 'service_id', 'desc': 'Service ID',
               'translator': value_trans},
-             {'fieldname': 'binary', 'translator': value_trans},
-             {'fieldname': 'host', 'translator': value_trans},
-             {'fieldname': 'zone', 'translator': value_trans},
-             {'fieldname': 'status', 'translator': value_trans},
-             {'fieldname': 'state', 'translator': value_trans},
-             {'fieldname': 'updated_at', 'translator': value_trans},
-             {'fieldname': 'disabled_reason', 'translator': value_trans})}
+             {'fieldname': 'binary', 'desc': 'Service binary',
+              'translator': value_trans},
+             {'fieldname': 'host', 'desc': 'Host Name',
+              'translator': value_trans},
+             {'fieldname': 'zone', 'desc': 'Availability Zone',
+              'translator': value_trans},
+             {'fieldname': 'status', 'desc': 'Status of service',
+              'translator': value_trans},
+             {'fieldname': 'state', 'desc': 'State of service',
+              'translator': value_trans},
+             {'fieldname': 'updated_at', 'desc': 'Last updated time',
+              'translator': value_trans},
+             {'fieldname': 'disabled_reason', 'desc': 'Disabled reason',
+              'translator': value_trans})}
+
+    availability_zones_translator = {
+        'translation-type': 'HDICT',
+        'table-name': AVAILABILITY_ZONES,
+        'selector-type': 'DOT_SELECTOR',
+        'field-translators':
+            ({'fieldname': 'zoneName', 'col': 'zone',
+              'desc': 'Availability zone name', 'translator': value_trans},
+             {'fieldname': 'zoneState', 'col': 'state',
+              'desc': 'Availability zone state',
+              'translator': value_trans})}
 
     TRANSLATORS = [servers_translator, flavors_translator, hosts_translator,
-                   floating_ips_translator, services_translator]
+                   services_translator, availability_zones_translator]
 
-    def __init__(self, name='', keys='', inbox=None, datapath=None, args=None):
-        super(NovaDriver, self).__init__(name, keys, inbox, datapath, args)
+    def __init__(self, name='', args=None):
+        super(NovaDriver, self).__init__(name, args)
         datasource_driver.ExecutionDriver.__init__(self)
-        self.creds = self.get_nova_credentials_v2(args)
-        self.nova_client = novaclient.client.Client(**self.creds)
+        self.creds = args
+        session = ds_utils.get_keystone_session(self.creds)
+        self.nova_client = novaclient.client.Client(
+            version=self.creds.get('api_version', '2'), session=session)
         self.add_executable_method('servers_set_meta',
                                    [{'name': 'server',
                                     'description': 'server id'},
-                                    {'name': 'meta',
-                                     'description': 'metadata pairs, ' +
-                                     'e.g. meta1=val1 meta2=val2'}],
+                                    {'name': 'meta-key1',
+                                     'description': 'meta key 1'},
+                                    {'name': 'meta-value1',
+                                     'description': 'value for meta key1'},
+                                    {'name': 'meta-keyN',
+                                     'description': 'meta key N'},
+                                    {'name': 'meta-valueN',
+                                     'description': 'value for meta keyN'}],
                                    "A wrapper for servers.set_meta()")
-        self.inspect_builtin_methods(self.nova_client, 'novaclient.v2.')
+        self.add_executable_client_methods(self.nova_client, 'novaclient.v2.')
+        self.initialize_update_methods()
         self._init_end_start_poll()
 
     @staticmethod
@@ -140,26 +200,32 @@ class NovaDriver(datasource_driver.DataSourceDriver,
         result['description'] = ('Datasource driver that interfaces with '
                                  'OpenStack Compute aka nova.')
         result['config'] = ds_utils.get_openstack_required_config()
+        result['config']['api_version'] = constants.OPTIONAL
+        result['config']['lazy_tables'] = constants.OPTIONAL
         result['secret'] = ['password']
         return result
 
-    def get_nova_credentials_v2(self, creds):
-        d = {}
-        d['version'] = '2'
-        d['username'] = creds['username']
-        d['api_key'] = creds['password']
-        d['auth_url'] = creds['auth_url']
-        d['project_id'] = creds['tenant_name']
-        return d
+    def initialize_update_methods(self):
+        servers_method = lambda: self._translate_servers(
+            self.nova_client.servers.list(
+                detailed=True, search_opts={"all_tenants": 1}))
+        self.add_update_method(servers_method, self.servers_translator)
 
-    def update_from_datasource(self):
-        servers = self.nova_client.servers.list(
-            detailed=True, search_opts={"all_tenants": 1})
-        self._translate_servers(servers)
-        self._translate_flavors(self.nova_client.flavors.list())
-        self._translate_hosts(self.nova_client.hosts.list())
-        self._translate_floating_ips(self.nova_client.floating_ips.list())
-        self._translate_services(self.nova_client.services.list())
+        flavors_method = lambda: self._translate_flavors(
+            self.nova_client.flavors.list())
+        self.add_update_method(flavors_method, self.flavors_translator)
+
+        hosts_method = lambda: self._translate_hosts(
+            self.nova_client.hosts.list())
+        self.add_update_method(hosts_method, self.hosts_translator)
+
+        services_method = lambda: self._translate_services(
+            self.nova_client.services.list())
+        self.add_update_method(services_method, self.services_translator)
+
+        az_method = lambda: self._translate_availability_zones(
+            self.nova_client.availability_zones.list())
+        self.add_update_method(az_method, self.availability_zones_translator)
 
     @ds_utils.update_state_on_changed(SERVERS)
     def _translate_servers(self, obj):
@@ -176,17 +242,18 @@ class NovaDriver(datasource_driver.DataSourceDriver,
         row_data = NovaDriver.convert_objs(obj, NovaDriver.hosts_translator)
         return row_data
 
-    @ds_utils.update_state_on_changed(FLOATING_IPS)
-    def _translate_floating_ips(self, obj):
-        row_data = NovaDriver.convert_objs(obj,
-                                           NovaDriver.floating_ips_translator)
-        return row_data
-
     @ds_utils.update_state_on_changed(SERVICES)
     def _translate_services(self, obj):
         row_data = NovaDriver.convert_objs(obj, NovaDriver.services_translator)
         return row_data
 
+    @ds_utils.update_state_on_changed(AVAILABILITY_ZONES)
+    def _translate_availability_zones(self, obj):
+        row_data = NovaDriver.convert_objs(
+            obj,
+            NovaDriver.availability_zones_translator)
+        return row_data
+
     def execute(self, action, action_args):
         """Overwrite ExecutionDriver.execute()."""
         # action can be written as a method or an API call.
@@ -203,7 +270,7 @@ class NovaDriver(datasource_driver.DataSourceDriver,
         'execute[p(x)]' doesn't take optional args at the moment.
         Therefore, this function translates the positional ARGS
         to optional args and call the servers.set_meta() api.
-        :param <list> args: expected server ID and pairs of meta
+        :param: <list> args: expected server ID and pairs of meta
         data in positional args such as:
         {'positional': ['server_id', 'meta1', 'value1', 'meta2', 'value2']}
 
