@@ -16,11 +16,8 @@
 import json
 import six
 
-
-import eventlet
-eventlet.monkey_patch()  # for using oslo.messaging w/ eventlet executor
-
 from oslo_config import cfg
+from oslo_db import exception as db_exc
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_messaging import exceptions as messaging_exceptions
@@ -47,11 +44,12 @@ class DseNode(object):
     communication between data services uses the DseNode interface.
 
     Attributes:
-        node_id: The unique ID of this node on the DSE.
-        messaging_config: Configuration options for the message bus.  See
-                          oslo.messaging for more details.
-        node_rpc_endpoints: List of object instances exposing a remotely
-                            invokable interface.
+
+    - node_id: The unique ID of this node on the DSE.
+    - messaging_config: Configuration options for the message bus.  See
+      oslo.messaging for more details.
+    - node_rpc_endpoints: List of object instances exposing a remotely
+      invokable interface.
     """
     RPC_VERSION = '1.0'
     EXCHANGE = 'congress'
@@ -100,14 +98,16 @@ class DseNode(object):
         # uuid to help recognize node_id clash
         self.instance = uuidutils.generate_uuid()
         # TODO(dse2): add detection and logging/rectifying for node_id clash?
+        access_policy = dispatcher.DefaultRPCAccessPolicy
         self.context = self._message_context()
-        self.transport = messaging.get_transport(
+        self.transport = messaging.get_rpc_transport(
             self.messaging_config,
-            allowed_remote_exmods=[exception.__name__, dispatcher.__name__, ])
+            allowed_remote_exmods=[exception.__name__, dispatcher.__name__,
+                                   db_exc.__name__, ])
         self._rpctarget = self.node_rpc_target(self.node_id, self.node_id)
         self._rpc_server = messaging.get_rpc_server(
             self.transport, self._rpctarget, self.node_rpc_endpoints,
-            executor='eventlet')
+            executor='eventlet', access_policy=access_policy)
 
         # # keep track of what publisher/tables local services subscribe to
         # subscribers indexed by publisher and table:
@@ -141,7 +141,7 @@ class DseNode(object):
             msg = ('Service %s already exsists on the node %s'
                    % (service.service_id, self.node_id))
             raise exception.DataServiceError(msg)
-
+        access_policy = dispatcher.DefaultRPCAccessPolicy
         service.always_snapshot = self.always_snapshot
         service.node = self
         self._services.append(service)
@@ -149,7 +149,7 @@ class DseNode(object):
                                                   server=self.node_id)
         service._rpc_server = messaging.get_rpc_server(
             self.transport, service._target, service.rpc_endpoints(),
-            executor='eventlet')
+            executor='eventlet', access_policy=access_policy)
 
         if self._running:
             service.start()
@@ -159,7 +159,7 @@ class DseNode(object):
 
     # Note(thread-safety): blocking function
     def unregister_service(self, service_id=None, uuid_=None):
-        """Unregister service from DseNode matching on service_id or uuid_
+        """Unregister service from DseNode matching on service_id or uuid\_
 
         Only one should be supplied. No-op if no matching service found.
         """
@@ -193,7 +193,7 @@ class DseNode(object):
     def service_object(self, service_id=None, uuid_=None):
         """Return the service object requested.
 
-        Search by service_id or uuid_ (only one should be supplied).
+        Search by service_id or uuid\_ (only one should be supplied).
         None if not found.
         """
         if service_id is not None:
@@ -258,15 +258,13 @@ class DseNode(object):
     def invoke_node_rpc(self, node_id, method, kwargs=None, timeout=None):
         """Invoke RPC method on a DSE Node.
 
-        Args:
-            node_id: The ID of the node on which to invoke the call.
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: node_id: The ID of the node on which to invoke the call.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            The result of the method invocation.
+        :returns: The result of the method invocation.
 
-        Raises: MessagingTimeout, RemoteError, MessageDeliveryFailure
+        :raises: MessagingTimeout, RemoteError, MessageDeliveryFailure
         """
         if kwargs is None:
             kwargs = {}
@@ -279,14 +277,13 @@ class DseNode(object):
     def broadcast_node_rpc(self, method, kwargs=None):
         """Invoke RPC method on all DSE Nodes.
 
-        Args:
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            None - Methods are invoked asynchronously and results are dropped.
+        :returns: None
+                  Methods are invoked asynchronously and results are dropped.
 
-        Raises: RemoteError, MessageDeliveryFailure
+        :raises: RemoteError, MessageDeliveryFailure
         """
         if kwargs is None:
             kwargs = {}
@@ -301,15 +298,15 @@ class DseNode(object):
             retry=None):
         """Invoke RPC method on a DSE Service.
 
-        Args:
-            service_id: The ID of the data service on which to invoke the call.
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: service_id: The ID of the data service on which to invoke the
+            call.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            The result of the method invocation.
+        :returns: The result of the method invocation.
 
-        Raises: MessagingTimeout, RemoteError, MessageDeliveryFailure, NotFound
+        :raises: MessagingTimeout, RemoteError, MessageDeliveryFailure,
+                 NotFound
         """
         target = self.service_rpc_target(
             service_id, server=(self.node_id if local else None))
@@ -349,15 +346,15 @@ class DseNode(object):
     def broadcast_service_rpc(self, service_id, method, kwargs=None):
         """Invoke RPC method on all instances of service_id.
 
-        Args:
-            service_id: The ID of the data service on which to invoke the call.
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: service_id: The ID of the data service on which to invoke the
+                call.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            None - Methods are invoked asynchronously and results are dropped.
+        :returns: None - Methods are invoked asynchronously and results are
+                  dropped.
 
-        Raises: RemoteError, MessageDeliveryFailure
+        :raises: RemoteError, MessageDeliveryFailure
         """
         if kwargs is None:
             kwargs = {}
@@ -376,15 +373,15 @@ class DseNode(object):
     def publish_table(self, publisher, table, data):
         """Invoke RPC method on all insances of service_id.
 
-        Args:
-            service_id: The ID of the data service on which to invoke the call.
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: service_id: The ID of the data service on which to invoke the
+            call.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            None - Methods are invoked asynchronously and results are dropped.
+        :returns: None
+                  Methods are invoked asynchronously and results are dropped.
 
-        Raises: RemoteError, MessageDeliveryFailure
+        :raises: RemoteError, MessageDeliveryFailure
         """
         LOG.trace("<%s> Publishing from '%s' table %s: %s",
                   self.node_id, publisher, table, data)
@@ -397,15 +394,15 @@ class DseNode(object):
             self, publisher, table, data, is_snapshot, seqnum):
         """Invoke RPC method on all insances of service_id.
 
-        Args:
-            service_id: The ID of the data service on which to invoke the call.
-            method: The method name to call.
-            kwargs: A dict of method arguments.
+        :param: service_id: The ID of the data service on which to invoke the
+            call.
+        :param: method: The method name to call.
+        :param: kwargs: A dict of method arguments.
 
-        Returns:
-            None - Methods are invoked asynchronously and results are dropped.
+        :returns: None
+                  Methods are invoked asynchronously and results are dropped.
 
-        Raises: RemoteError, MessageDeliveryFailure
+        :raises: RemoteError, MessageDeliveryFailure
         """
         LOG.trace("<%s> Publishing from '%s' table %s: %s",
                   self.node_id, publisher, table, data)
@@ -650,14 +647,14 @@ class DseNode(object):
     def create_datasource_service(self, datasource):
         """Create a new DataService on this node.
 
-        :param name is the name of the service.  Must be unique across all
+        :param: name is the name of the service.  Must be unique across all
                services
-        :param classPath is a string giving the path to the class name, e.g.
+        :param: classPath is a string giving the path to the class name, e.g.
                congress.datasources.fake_datasource.FakeDataSource
-        :param args is the list of arguments to give the DataService
+        :param: args is the list of arguments to give the DataService
                constructor
-        :param type_ is the kind of service
-        :param id_ is an optional parameter for specifying the uuid.
+        :param: type\_ is the kind of service
+        :param: id\_ is an optional parameter for specifying the uuid.
         """
         # get the driver info for the datasource
         ds_dict = self.make_datasource_dict(datasource)
