@@ -71,7 +71,7 @@ class TestParser(base.TestCase):
         event = event[0]
         fact = compile.parse1('p(1) :- true')
         self.assertEqual(event.formula, fact)
-        self.assertEqual(event.insert, True)
+        self.assertTrue(event.insert)
         self.assertIsNone(event.target)
 
         # delete
@@ -80,7 +80,7 @@ class TestParser(base.TestCase):
         event = event[0]
         fact = compile.parse1('p(1) :- true')
         self.assertEqual(event.formula, fact)
-        self.assertEqual(event.insert, False)
+        self.assertFalse(event.insert)
         self.assertIsNone(event.target)
 
         # insert with policy
@@ -89,7 +89,7 @@ class TestParser(base.TestCase):
         event = event[0]
         fact = compile.parse1('p(1) :- true')
         self.assertEqual(event.formula, fact)
-        self.assertEqual(event.insert, True)
+        self.assertTrue(event.insert)
         self.assertEqual(event.target, "policy")
 
     def test_event_rules(self):
@@ -102,7 +102,7 @@ class TestParser(base.TestCase):
         self.assertEqual(len(event), 1)
         event = event[0]
         self.assertEqual(event.formula, pqrule)
-        self.assertEqual(event.insert, True)
+        self.assertTrue(event.insert)
         self.assertIsNone(event.target)
 
         # rule-level modal with delete
@@ -110,7 +110,7 @@ class TestParser(base.TestCase):
         self.assertEqual(len(event), 1)
         event = event[0]
         self.assertEqual(event.formula, pqrule)
-        self.assertEqual(event.insert, False)
+        self.assertFalse(event.insert)
         self.assertIsNone(event.target)
 
         # embedded modals
@@ -119,7 +119,7 @@ class TestParser(base.TestCase):
         event = event[0]
         rule = compile.parse1('execute[p(x)] :- q(x)')
         self.assertEqual(event.formula, rule)
-        self.assertEqual(event.insert, True)
+        self.assertTrue(event.insert)
         self.assertIsNone(event.target)
 
         # rule-level modal with policy name
@@ -127,7 +127,7 @@ class TestParser(base.TestCase):
         self.assertEqual(len(event), 1)
         event = event[0]
         self.assertEqual(event.formula, pqrule)
-        self.assertEqual(event.insert, True)
+        self.assertTrue(event.insert)
         self.assertEqual(event.target, "policy")
 
     def test_modal_execute(self):
@@ -242,7 +242,7 @@ class TestColumnReferences(base.TestCase):
             except exception.PolicyException as e:
                 emsg = "Err message '{}' should include '{}'".format(
                     str(e), errmsg)
-                self.assertTrue(errmsg in str(e), msg + ": " + emsg)
+                self.assertIn(errmsg, str(e), msg + ": " + emsg)
 
         check_err(
             'p(x) :- nova:q(id=x, status=x, id=y)',
@@ -264,6 +264,83 @@ class TestColumnReferences(base.TestCase):
             '1 is already provided by position arguments',
             'Conflict between name and position')
 
+    def test_positional_args_padding_atom(self):
+        """Test positional args padding on a single atom."""
+        def check_err(rule, errmsg, msg):
+            rule = compile.parse1(rule)
+            try:
+                rule.eliminate_column_references_and_pad_positional(theories)
+                self.fail("Failed to throw error {}".format(errmsg))
+            except (exception.PolicyException,
+                    exception.IncompleteSchemaException) as e:
+                emsg = "Err messages '{}' should include '{}'".format(
+                    str(e), errmsg)
+                self.assertIn(errmsg, str(e), msg + ": " + emsg)
+
+        def check(code, correct, msg, no_theory=False):
+            actual = compile.parse1(
+                code).eliminate_column_references_and_pad_positional(
+                    {} if no_theory else theories)
+            eq = helper.datalog_same(str(actual), correct)
+            self.assertTrue(eq, msg)
+
+        run = agnostic.Runtime()
+        run.create_policy('nova')
+        schema = compile.Schema({'q': ('id', 'name', 'status')})
+        theories = {'nova': self.SchemaWrapper(schema)}
+
+        # Too few positional args
+        code = ("p(x) :- nova:q(w, y)")
+        correct = "p(x) :- nova:q(w, y, x3)"
+        check(code, correct, 'Too few positional args')
+
+        code = ("p(x) :- nova:q(w)")
+        correct = "p(x) :- nova:q(w, y, x3)"
+        check(code, correct, 'Too few positional args')
+
+        code = ("p(x) :- nova:q()")
+        correct = "p(x) :- nova:q(w, y, x3)"
+        check(code, correct, 'Too few (no) positional args')
+
+        # No schema provided, no change
+        code = ("p(x) :- nova:q(w, y)")
+        correct = "p(x) :- nova:q(w, y)"
+        check(code, correct, 'No schema provided', True)
+
+        code = ("p(x) :- nova:q(w, x, y, z)")
+        correct = "p(x) :- nova:q(w, x, y, z)"
+        check(code, correct, 'No schema provided', True)
+
+    def test_positional_args_padding_multiple_atoms(self):
+        """Test positional args padding on a single atom."""
+        def check(code, correct, msg, no_theory=False):
+            actual = compile.parse1(
+                code).eliminate_column_references_and_pad_positional(
+                    {} if no_theory else theories)
+            eq = helper.datalog_same(str(actual), correct)
+            self.assertTrue(eq, msg)
+
+        run = agnostic.Runtime()
+        run.create_policy('nova')
+        schema = compile.Schema({'q': ('id', 'name', 'status'),
+                                 'r': ('id', 'age', 'weight')})
+        theories = {'nova': self.SchemaWrapper(schema)}
+
+        # Multiple atoms, no shared variable
+        code = ("p(x) :- nova:q(x, y), nova:r(w)")
+        correct = "p(x) :- nova:q(x, y, z0), nova:r(w, y0, y1)"
+        check(code, correct, 'Multiple atoms')
+
+        # Multiple atoms, some shared variable
+        code = ("p(x) :- nova:q(x, y), nova:r(x)")
+        correct = "p(x) :- nova:q(x, y, z0), nova:r(x, y0, y1)"
+        check(code, correct, 'Multiple atoms')
+
+        # Multiple atoms, same table
+        code = ("p(x) :- nova:q(x, y), nova:q(x)")
+        correct = "p(x) :- nova:q(x, y, z0), nova:q(x, w0, w1)"
+        check(code, correct, 'Multiple atoms, same table')
+
     def test_column_references_validation_errors(self):
         """Test invalid column references occurring in a single atom."""
         schema = compile.Schema({'q': ('id', 'name', 'status'),
@@ -274,13 +351,13 @@ class TestColumnReferences(base.TestCase):
         def check_err(rule, errmsg, msg):
             rule = compile.parse1(rule)
             try:
-                rule.eliminate_column_references(theories)
+                rule.eliminate_column_references_and_pad_positional(theories)
                 self.fail("Failed to throw error {}".format(errmsg))
             except (exception.PolicyException,
                     exception.IncompleteSchemaException) as e:
                 emsg = "Err messages '{}' should include '{}'".format(
                     str(e), errmsg)
-                self.assertTrue(errmsg in str(e), msg + ": " + emsg)
+                self.assertIn(errmsg, str(e), msg + ": " + emsg)
 
         check_err(
             'p(x) :- nova:missing(id=x)',
@@ -316,7 +393,8 @@ class TestColumnReferences(base.TestCase):
     def test_column_references_atom(self):
         """Test column references occurring in a single atom in a rule."""
         def check(code, correct, msg):
-            actual = compile.parse1(code).eliminate_column_references(theories)
+            actual = compile.parse1(
+                code).eliminate_column_references_and_pad_positional(theories)
             eq = helper.datalog_same(str(actual), correct)
             self.assertTrue(eq, msg)
 
@@ -376,10 +454,13 @@ class TestColumnReferences(base.TestCase):
         correct = "p(x) :- nova:q(x, y, z)"
         check(code, correct, 'Pure positional without schema')
 
+        # Too few pure positional EKCS
+
     def test_column_references_multiple_atoms(self):
         """Test column references occurring in multiple atoms in a rule."""
         def check(code, correct, msg):
-            actual = compile.parse1(code).eliminate_column_references(theories)
+            actual = compile.parse1(
+                code).eliminate_column_references_and_pad_positional(theories)
             eq = helper.datalog_same(str(actual), correct)
             self.assertTrue(eq, msg)
 
@@ -412,10 +493,12 @@ class TestColumnReferences(base.TestCase):
                                  'r': ('id', 'age', 'weight')})
         theories = {'nova': self.SchemaWrapper(schema)}
 
-        rule1 = compile.parse1("p(x) :- nova:q(id=x, 2=y), nova:r(id=x)"
-                               ).eliminate_column_references(theories)
-        rule2 = compile.parse1("p(x) :- nova:r(id=x), nova:q(id=x, 2=y)"
-                               ).eliminate_column_references(theories)
+        rule1 = compile.parse1(
+            "p(x) :- nova:q(id=x, 2=y), nova:r(id=x)"
+            ).eliminate_column_references_and_pad_positional(theories)
+        rule2 = compile.parse1(
+            "p(x) :- nova:r(id=x), nova:q(id=x, 2=y)"
+            ).eliminate_column_references_and_pad_positional(theories)
         self.assertEqual(rule1, rule2, 'eliminate_column_references failed to '
                                        'preserve order insensitivity')
 
@@ -633,13 +716,13 @@ class TestCompiler(base.TestCase):
         schema.revert(change2)
         self.assertEqual(schema.count['p'], 1)
         schema.revert(change1)
-        self.assertEqual('p' in schema.count, False)
+        self.assertNotIn('p', schema.count)
 
         schema.update(rule1.head, True)
         schema.update(rule2.head, True)
         change1 = schema.update(rule1.head, False)
         change2 = schema.update(rule2.head, False)
-        self.assertEqual('p' in schema.count, False)
+        self.assertNotIn('p', schema.count)
         schema.revert(change2)
         self.assertEqual(schema.count['p'], 1)
         schema.revert(change1)
