@@ -13,23 +13,77 @@
 #    under the License.
 #
 
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
 import json
 import os
+
+import tenacity
 import time
 
+from oslo_config import cfg
 from oslo_log import log as logging
-import retrying
+from oslo_messaging import conffixture
 
 from congress.datalog import compile
 from congress.datalog import unify
 from congress.policy_engines import agnostic
 
+from congress.dse2 import dse_node
+
 
 LOG = logging.getLogger(__name__)
 
 ROOTDIR = os.path.dirname(__file__)
 ETCDIR = os.path.join(ROOTDIR, 'etc')
 
+# single, global variable used to ensure different tests from
+#  different subclasses of TestCase all can get a unique ID
+#  so that the tests do not interact on oslo-messaging
+partition_counter = 0
+
+
+def make_dsenode_new_partition(node_id,
+                               messaging_config=None,
+                               node_rpc_endpoints=None):
+    """Get new DseNode in it's own new DSE partition."""
+    messaging_config = messaging_config or generate_messaging_config()
+    node_rpc_endpoints = node_rpc_endpoints or []
+    return dse_node.DseNode(messaging_config, node_id, node_rpc_endpoints,
+                            partition_id=get_new_partition())
+
+
+def make_dsenode_same_partition(existing,
+                                node_id,
+                                messaging_config=None,
+                                node_rpc_endpoints=None):
+    """Get new DseNode in the same DSE partition as existing (node or part)."""
+    partition_id = (existing.partition_id if
+                    isinstance(existing, dse_node.DseNode) else existing)
+
+    messaging_config = messaging_config or generate_messaging_config()
+    node_rpc_endpoints = node_rpc_endpoints or []
+    return dse_node.DseNode(
+        messaging_config, node_id, node_rpc_endpoints, partition_id)
+
+
+def get_new_partition():
+    """Create a new partition number, unique within each process."""
+    global partition_counter
+    old = partition_counter
+    partition_counter += 1
+    return old
+
+
+def generate_messaging_config():
+    mc_fixture = conffixture.ConfFixture(cfg.CONF)
+    mc_fixture.conf.transport_url = 'kombu+memory://'
+    messaging_config = mc_fixture.conf
+    messaging_config.rpc_response_timeout = 10
+    return messaging_config
+
 
 def etcdir(*p):
     return os.path.join(ETCDIR, *p)
@@ -76,10 +130,12 @@ def api_module_path():
     return path
 
 
-def test_path():
-    """Return path to root of top-level tests."""
+def test_path(file=None):
+    """Return path to root of top-level tests. Joined with file if provided."""
     path = source_path()
     path = os.path.join(path, "tests")
+    if file is not None:
+        path = os.path.join(path, file)
     return path
 
 
@@ -95,7 +151,8 @@ def datasource_openstack_args():
     return {'username': '',
             'password': '',
             'auth_url': '',
-            'tenant_name': ''}
+            'tenant_name': '',
+            'poll_time': 1}
 
 
 def pause(factor=1):
@@ -197,39 +254,51 @@ def form2str(formula):
     return str(formula)
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
+def retry_check_for_last_message(obj):
+    if not hasattr(obj, "last_msg"):
+        raise AttributeError("Missing 'last_msg' attribute")
+
+
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_for_message_to_arrive(obj):
     if not hasattr(obj.msg, "body"):
         raise AttributeError("Missing 'body' attribute")
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_for_message_data(obj, data):
     if not hasattr(obj.msg, "body"):
         raise AttributeError("Missing 'body' attribute")
     if obj.get_msg_data() != data:
-        raise Exception("Missing expected data in msg")
+        raise TestFailureException("Missing expected data in msg")
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_nonempty_last_policy_change(obj):
     if not hasattr(obj, "last_policy_change"):
         raise AttributeError("Missing 'last_policy_change' attribute")
     if obj.last_policy_change is None:
-        raise Exception("last_policy_change == None")
+        raise TestFailureException("last_policy_change == None")
     if len(obj.last_policy_change) == 0:
-        raise Exception("last_policy_change == 0")
+        raise TestFailureException("last_policy_change == 0")
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_empty_last_policy_change(obj):
     if not hasattr(obj, "last_policy_change"):
         raise AttributeError("Missing 'last_policy_change' attribute")
     if len(obj.last_policy_change) != 0:
-        raise Exception("last_policy_change != 0")
+        raise TestFailureException("last_policy_change != 0")
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_db_equal(policy, query, correct, target=None):
     if not hasattr(policy, "select"):
         raise AttributeError("Missing 'select' attribute")
@@ -238,24 +307,28 @@ def retry_check_db_equal(policy, query, correct, target=None):
     else:
         actual = policy.select(query, target=target)
     if not db_equal(actual, correct, output_diff=False):
-        raise Exception("Query {} produces {}, should produce {}".format(
-            str(query), str(actual), str(correct)))
+        raise TestFailureException(
+            "Query {} produces {}, should produce {}".format(
+                str(query), str(actual), str(correct)))
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_number_of_updates(deepsix, value):
     if not hasattr(deepsix, "number_of_updates"):
         raise AttributeError("Missing 'number_of_updates' attribute")
     if deepsix.number_of_updates != value:
-        raise Exception("number_of_updates is {}, not {}".format(
+        raise TestFailureException("number_of_updates is {}, not {}".format(
             deepsix.number_of_updates, value))
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_subscriptions(deepsix, subscription_list):
     if not check_subscriptions(deepsix, subscription_list):
-        raise Exception("{} does not have subscription list {}".format(
-            deepsix.name, str(subscription_list)))
+        raise TestFailureException(
+            "{} does not have subscription list {}".format(
+                deepsix.name, str(subscription_list)))
 
 
 def check_subscriptions(deepsix, subscription_list):
@@ -274,49 +347,97 @@ def check_subscriptions(deepsix, subscription_list):
     return not missing
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_subscribers(deepsix, subscriber_list):
     if not check_subscribers(deepsix, subscriber_list):
-        raise Exception("{} does not have subscriber list {}".format(
-            deepsix.name, str(subscriber_list)))
+        raise TestFailureException(
+            "{} does not have subscriber list {}".format(
+                deepsix.name, str(subscriber_list)))
 
 
-@retrying.retry(stop_max_attempt_number=1000, wait_fixed=100)
+@tenacity.retry(stop=tenacity.stop_after_attempt(1000),
+                wait=tenacity.wait_fixed(0.1))
 def retry_check_no_subscribers(deepsix, subscriber_list):
-    if check_subscribers(deepsix, subscriber_list):
-        raise Exception("{} still has subscriber list {}".format(
-            deepsix.name, str(subscriber_list)))
+    """Check that deepsix has none of the subscribers in subscriber_list"""
+    if check_subscribers(deepsix, subscriber_list, any_=True):
+        raise TestFailureException(
+            "{} still has some subscribers in list {}".format(
+                deepsix.name, str(subscriber_list)))
 
 
-def check_subscribers(deepsix, subscriber_list):
+def check_subscribers(deepsix, subscriber_list, any_=False):
     """Check subscribers.
 
     Check that the instance DEEPSIX includes subscriptions for all of
     the (name, dataindex) pairs in SUBSCRIBER_LIST.  Return True if
     all subscribers exist; otherwise returns False.
+
+    If any_=True, then return True if ANY subscribers exist in subscriber_list
     """
     actual = set([(name, pubdata.dataindex)
-                  for pubdata in deepsix.pubdata.values()
+                  for pubdata in deepsix.pubdata.copy().values()
                   for name in pubdata.subscribers])
     correct = set(subscriber_list)
     missing = correct - actual
     if missing:
         LOG.debug("Missing name/dataindex subscribers: %s", missing)
+    if any_:
+        return (len(missing) < len(actual))
     return not missing
 
 
-@retrying.retry(stop_max_attempt_number=10, wait_fixed=500)
+@tenacity.retry(stop=tenacity.stop_after_attempt(20),
+                wait=tenacity.wait_fixed(1))
 def retry_check_function_return_value(f, expected_value):
     """Check if function f returns expected key."""
-    if f() != expected_value:
-        raise Exception("Expected value '%s' not received" % expected_value)
+    result = f()
+    if result != expected_value:
+        raise TestFailureException(
+            "Expected value '%s' not received.  "
+            "Got %s instead." % (expected_value, result))
 
 
-@retrying.retry(stop_max_attempt_number=10, wait_fixed=500)
+@tenacity.retry(stop=tenacity.stop_after_attempt(10),
+                wait=tenacity.wait_fixed(0.5))
 def retry_check_function_return_value_not_eq(f, value):
     """Check if function f does not return expected value."""
-    if f() == value:
-        raise Exception("Actual value '%s' not different from '%s'" % value)
+    result = f()
+    if result == value:
+        raise TestFailureException(
+            "Actual value '%s' should be different "
+            "from '%s'" % (result, value))
+
+
+@tenacity.retry(stop=tenacity.stop_after_attempt(10),
+                wait=tenacity.wait_fixed(0.5))
+def retry_til_exception(expected_exception, f):
+    """Check if function f does not return expected value."""
+    try:
+        val = f()
+        raise TestFailureException("No exception thrown; received %s" % val)
+    except expected_exception:
+        return
+    except Exception as e:
+        raise TestFailureException("Wrong exception thrown: %s" % e)
+
+
+@tenacity.retry(stop=tenacity.stop_after_attempt(20),
+                wait=tenacity.wait_fixed(1))
+def retry_check_function_return_value_table(f, expected_values):
+    """Check if function f returns expected table."""
+    result = f()
+    actual = set(tuple(x) for x in result)
+    correct = set(tuple(x) for x in expected_values)
+    extra = actual - correct
+    missing = correct - actual
+    if len(extra) > 0 or len(missing) > 0:
+        s = "Actual: %s\nExpected: %s\n" % (result, expected_values)
+        if len(extra) > 0:
+            s += "Extra: %s\n" % extra
+        if len(missing) > 0:
+            s += "Missing: %s\n" % missing
+        raise TestFailureException(s)
 
 
 class FakeRequest(object):
@@ -324,6 +445,16 @@ class FakeRequest(object):
         self.body = json.dumps(body)
 
 
-class FakeServiceObj():
+class FakeServiceObj(object):
     def __init__(self):
         self.state = {}
+
+
+class TestFailureException(Exception):
+    """Custom exception thrown on test failure
+
+    Facilitates using assertRaises to check for failure on retry tests
+    (generic Exception in assertRaises disallowed by pep8 check/gate)
+    """
+    def __init__(self, *args, **kwargs):
+        Exception.__init__(self, *args, **kwargs)
