@@ -259,12 +259,43 @@ class TestRuntime(base.TestCase):
                                              policy_name[:5],
                                              mock.ANY,
                                              'user',
-                                             'nonrecursive')
+                                             'nonrecursive',
+                                             session=mock.ANY)
             # mock_delete.assert_called_once_with(policy_name)
             self.assertFalse(mock_delete.called)
             self.assertFalse(run.synchronizer.sync_one_policy.called)
             self.assertNotIn('test_policy', run.policy_names())
 
+    mock_db_policy_obj = lambda: None
+    setattr(mock_db_policy_obj, 'name', 'test_policy')
+
+    @mock.patch.object(db_policy_rules, 'add_policy_rule')
+    @mock.patch.object(db_policy_rules, 'policy_name',
+                       side_effect=lambda x, session: x)
+    @mock.patch.object(
+        db_policy_rules, 'get_policies', return_value=[mock_db_policy_obj])
+    def test_persistent_insert_rules(
+            self, mock_add, mock_policy_name, mock_get_policies):
+        run = agnostic.Runtime()
+        run.synchronizer = mock.MagicMock()
+        run.create_policy('test_policy')
+
+        # test empty insert
+        result, _ = run.persistent_insert_rules('test_policy', [])
+        self.assertEqual(len(result), 0)
+        self.assertTrue(helper.datalog_equal(
+            run.select('p(x)'), ''))
+
+        # test duplicated insert, 3 rules, 2 unique
+        result, _ = run.persistent_insert_rules(
+            'test_policy',
+            [{'rule': 'p(1)', 'name': '', 'comment': ''},
+             {'rule': 'p(2)', 'name': '', 'comment': ''},
+             {'rule': 'p(1)', 'name': '', 'comment': ''}])
+        self.assertEqual(len(result), 2)
+        self.assertTrue(helper.datalog_equal(
+            run.select('p(x)'), 'p(1) p(2)'))
+
     def test_tablenames_theory_name(self):
         run = agnostic.Runtime()
         run.create_policy('test')
@@ -544,17 +575,39 @@ class TestTriggers(base.TestCase):
         run.insert('p(1)')
         self.assertEqual(0, obj.value)
 
-    def test_batch_change(self):
+    def test_batch_change_succeed(self):
         obj = self.MyObject()
         run = agnostic.Runtime()
         run.create_policy('test')
         run.register_trigger('p', lambda tbl, old, new: obj.increment())
         p1 = compile.parse1('p(1)')
-        result = run.update([compile.Event(p1, target='test')])
+        p2 = compile.parse1('p(2)')
+        p3 = compile.parse1('p(3)')
+        result = run.update([compile.Event(p1, target='test'),
+                             compile.Event(p2, target='test'),
+                             compile.Event(p3, target='test')])
         self.assertTrue(result[0], ("Update failed with errors: " +
                                     ";".join(str(x) for x in result[1])))
+        # IMPORTANT: 3 tuples inserted into p in a single batch triggers once
         self.assertEqual(1, obj.value)
 
+    def test_batch_change_fail(self):
+        obj = self.MyObject()
+        run = agnostic.Runtime()
+        run.create_policy('test')
+        run.register_trigger('p', lambda tbl, old, new: obj.increment())
+        p1 = compile.parse1('p(1)')
+        p2 = compile.parse1('p(x) :- q(x)')
+        p3 = compile.parse1('q(x) :- p(x)')
+        result = run.update([compile.Event(p1, target='test'),
+                             compile.Event(p2, target='test'),
+                             compile.Event(p3, target='test')])
+        self.assertFalse(result[0],
+                         ("Update should have failed with recursion: " +
+                          ";".join(str(x) for x in result[1])))
+        # IMPORTANT: trigger not activated even though initial events succeed
+        self.assertEqual(0, obj.value)
+
     def test_dependency(self):
         obj = self.MyObject()
         run = agnostic.Runtime()
@@ -1022,9 +1075,9 @@ class TestMultipolicyRules(base.TestCase):
             rule.head.table.table, run.policy_object(policy).schema)
         run.insert(rulestr, policy)
         run.delete(rulestr, policy)
-        self.assertFalse(rule in run.policy_object(policy))
-        self.assertFalse(
-            rule.head.table.table in run.policy_object(policy).schema)
+        self.assertNotIn(rule, run.policy_object(policy))
+        self.assertNotIn(
+            rule.head.table.table, run.policy_object(policy).schema)
 
 
 class TestSelect(base.TestCase):
@@ -1513,6 +1566,19 @@ class TestActionExecution(base.TestCase):
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
+    def test_insert_multiple_rules(self):
+        # basic test
+
+        # test recursion caused at nth rule
+
+        # test transactional trigger activation:
+        # e.g.
+        # a(1)
+        # trigger(x) :- a(x), not b(x)
+        # b(x) :- a(x)
+        # trigger should not be activated
+        pass
+
     def test_disjunction(self):
         run = self.run
         run.create_policy('test')
