@@ -128,7 +128,7 @@ class TestCongress(BaseTestPolicyCongress):
             lambda: self.query('q', 'alpha'), {'results': [{'data': (1,)}]})
 
         # TODO(dse2): enable rules to be inserted before data created.
-        #  Maybe just have subscription handle errors gracefull when
+        #  Maybe just have subscription handle errors graceful when
         #  asking for a snapshot and return [].
         # self.insert_rule('p(x) :- fake:fake_table(x)', 'alpha')
 
@@ -294,6 +294,9 @@ class TestCongress(BaseTestPolicyCongress):
         res = self.library.get_policies()
         self.assertEqual(res, [])
 
+    def test_load_library_policies(self):
+        self.assertEqual(self.library.load_policies_from_files(), 0)
+
 
 class APILocalRouting(BaseTestPolicyCongress):
 
