@@ -16,9 +16,13 @@
 #    under the License.
 
 """Utilities and helper functions."""
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
 
 import contextlib
 import json
+import os
 import shutil
 import tempfile
 
@@ -36,6 +40,7 @@ CONF = cfg.CONF
 CONF.register_opts(utils_opts)
 
 
+# Note(thread-safety): blocking function
 @contextlib.contextmanager
 def tempdir(**kwargs):
     argdict = kwargs.copy()
@@ -48,7 +53,7 @@ def tempdir(**kwargs):
         try:
             shutil.rmtree(tmpdir)
         except OSError as e:
-            LOG.error(_('Could not remove tmpdir: %s'), e)
+            LOG.error(('Could not remove tmpdir: %s'), e)
 
 
 def value_to_congress(value):
@@ -60,7 +65,8 @@ def value_to_congress(value):
             six.text_type(value).encode('ascii')
         except UnicodeEncodeError:
             LOG.warning('Ignoring non-ascii characters')
-        return six.text_type(value).encode('ascii', 'ignore')
+        # Py3: decode back into str for compat (bytes != str)
+        return six.text_type(value).encode('ascii', 'ignore').decode('ascii')
     # Check for bool before int, because True and False are also ints.
     elif isinstance(value, bool):
         return str(value)
@@ -70,6 +76,22 @@ def value_to_congress(value):
     return str(value)
 
 
+# Note(thread-safety): blocking function
+def create_datasource_policy(bus, datasource, engine):
+    # Get the schema for the datasource using
+    # Note(thread-safety): blocking call
+    schema = bus.rpc(datasource, 'get_datasource_schema',
+                     {'source_id': datasource})
+    # Create policy and sets the schema once datasource is created.
+    args = {'name': datasource, 'schema': schema}
+    # Note(thread-safety): blocking call
+    bus.rpc(engine, 'initialize_datasource', args)
+
+
+def get_root_path():
+    return os.path.dirname(os.path.dirname(__file__))
+
+
 class Location (object):
     """A location in the program source code."""
 
@@ -101,5 +123,37 @@ class Location (object):
 
 
 def pretty_json(data):
-    print (json.dumps(data, sort_keys=True,
-                      indent=4, separators=(',', ': ')))
+    print(json.dumps(data, sort_keys=True,
+                     indent=4, separators=(',', ': ')))
+
+
+def pretty_rule(rule_str):
+    # remove line breaks
+    rule_str = ''.join(
+        [line.strip() for line in rule_str.strip().splitlines()])
+
+    head_and_body = rule_str.split(':-')
+
+    # drop empty body
+    head_and_body = [item.strip()
+                     for item in head_and_body if len(item.strip()) > 0]
+
+    head = head_and_body[0]
+    if len(head_and_body) == 1:
+        return head
+    else:
+        body = head_and_body[1]
+        # split the literal by spliting on ')'
+        body_list = body.split(')')
+        body_list = body_list[:-1]  # drop part behind the final ')'
+
+        new_body_list = []
+        for literal in body_list:
+            # remove commas between literals
+            if literal[0] == ',':
+                literal = literal[1:]
+            # add back the ')', also add an indent
+            new_body_list.append('  ' + literal.strip() + ')')
+
+        pretty_rule_str = head + " :-\n" + ",\n".join(new_body_list)
+        return pretty_rule_str
