@@ -25,7 +25,7 @@ set +o xtrace
 # Test if any Congress services are enabled
 # is_congress_enabled
 function is_congress_enabled {
-    [[ ,${ENABLED_SERVICES} =~ ,"congress" ]] && return 0
+    [[ ,${ENABLED_SERVICES//congress-agent/} =~ ,"congress" ]] && return 0
     return 1
 }
 
@@ -47,10 +47,8 @@ function configure_congress {
         setup_colorized_logging $CONGRESS_CONF DEFAULT project_id
     fi
     CONGRESS_API_PASTE_FILE=$CONGRESS_CONF_DIR/api-paste.ini
-    CONGRESS_POLICY_FILE=$CONGRESS_CONF_DIR/policy.json
 
     cp $CONGRESS_DIR/etc/api-paste.ini $CONGRESS_API_PASTE_FILE
-    cp $CONGRESS_DIR/etc/policy.json $CONGRESS_POLICY_FILE
     if [[ ! -d $CONGRESS_LIBRARY_DIR ]]; then
         mkdir $CONGRESS_LIBRARY_DIR
     fi
@@ -58,20 +56,16 @@ function configure_congress {
 
     # Update either configuration file
     iniset $CONGRESS_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
-    iniset $CONGRESS_CONF oslo_policy policy_file $CONGRESS_POLICY_FILE
     iniset $CONGRESS_CONF DEFAULT auth_strategy $CONGRESS_AUTH_STRATEGY
     iniset $CONGRESS_CONF DEFAULT datasource_sync_period 30
     iniset $CONGRESS_CONF DEFAULT replicated_policy_engine "$CONGRESS_REPLICATED"
-
-    # if [ "$CONGRESS_MULTIPROCESS_DEPLOYMENT" == "False" ]; then
-    #    iniset $CONGRESS_CONF DEFAULT transport_url $CONGRESS_TRANSPORT_URL
-    # fi
+    iniset $CONGRESS_CONF DEFAULT transport_url rabbit://$RABBIT_USERID:$RABBIT_PASSWORD@$RABBIT_HOST:5672
 
     CONGRESS_DRIVERS="congress.datasources.neutronv2_driver.NeutronV2Driver,"
+    CONGRESS_DRIVERS+="congress.datasources.neutronv2_qos_driver.NeutronV2QosDriver,"
     CONGRESS_DRIVERS+="congress.datasources.glancev2_driver.GlanceV2Driver,"
     CONGRESS_DRIVERS+="congress.datasources.nova_driver.NovaDriver,"
     CONGRESS_DRIVERS+="congress.datasources.keystonev3_driver.KeystoneV3Driver,"
-    CONGRESS_DRIVERS+="congress.datasources.ceilometer_driver.CeilometerDriver,"
     CONGRESS_DRIVERS+="congress.datasources.cinder_driver.CinderDriver,"
     CONGRESS_DRIVERS+="congress.datasources.swift_driver.SwiftDriver,"
     CONGRESS_DRIVERS+="congress.datasources.plexxi_driver.PlexxiDriver,"
@@ -81,6 +75,8 @@ function configure_congress {
     CONGRESS_DRIVERS+="congress.datasources.heatv1_driver.HeatV1Driver,"
     CONGRESS_DRIVERS+="congress.datasources.doctor_driver.DoctorDriver,"
     CONGRESS_DRIVERS+="congress.datasources.aodh_driver.AodhDriver,"
+    CONGRESS_DRIVERS+="congress.datasources.cfgvalidator_driver.ValidatorDriver,"
+    CONGRESS_DRIVERS+="congress.datasources.mistral_driver.MistralDriver,"
     CONGRESS_DRIVERS+="congress.tests.fake_datasource.FakeDataSource"
 
     iniset $CONGRESS_CONF DEFAULT drivers $CONGRESS_DRIVERS
@@ -93,9 +89,9 @@ function configure_congress {
 
 function configure_congress_datasources {
     _configure_service neutron neutronv2
+    _configure_service neutron neutronv2_qos
     _configure_service nova nova
     _configure_service key keystonev3
-    _configure_service ceilometer ceilometer
     _configure_service cinder cinder
     _configure_service swift swift
     _configure_service glance glancev2
@@ -103,22 +99,49 @@ function configure_congress_datasources {
     _configure_service ironic ironic
     _configure_service heat heat
     _configure_service aodh aodh
+    _configure_service mistral mistral
+    if [[ $ENABLE_CONGRESS_AGENT == "True" ]] ; then
+        _configure_service congress-agent config
+    fi
+}
 
+function _configure_tempest {
+    # NOTE(gmann): Every service which are required by congress
+    # CI/CD has to be explicitly set here on Tempest. Devstack
+    # only set the Tempest in-tree configured service only which
+    # are - [nova, keystone, cinder, glance, swift, glance, neutron].
+    # service_available from Tempest plugin is not guaranteed to be
+    # set correctly due to different env setup scenario, so it is
+    # better to set it explicitly here.
+    local service
+    local required_services="heat,ironic,aodh,murano,mistral"
+    for service in ${required_services//,/ }; do
+        if is_service_enabled $service ; then
+            iniset $TEMPEST_CONFIG service_available $service "True"
+        else
+            iniset $TEMPEST_CONFIG service_available $service "False"
+        fi
+    done
 }
 
 function _configure_service {
     if is_service_enabled $1; then
-        openstack congress datasource create $2 "$2" \
-            --config poll_time=10 \
-            --config username=$OS_USERNAME \
-            --config tenant_name=$OS_PROJECT_NAME \
-            --config password=$OS_PASSWORD \
-            --config auth_url=http://$SERVICE_HOST/identity
+        if [ "$2" == "config" ] ; then
+            openstack congress datasource create $2 "$2" \
+                --config poll_time=10
+        else
+            openstack congress datasource create $2 "$2" \
+                --config poll_time=10 \
+                --config username=$OS_USERNAME \
+                --config tenant_name=$OS_PROJECT_NAME \
+                --config password=$OS_PASSWORD \
+                --config auth_url=http://$SERVICE_HOST/identity
+        fi
     fi
 }
 
 function create_predefined_policy {
-    if [ -n $CONGRESS_PREDEFINED_POLICY_FILE ] ; then
+    if [ -n "$CONGRESS_PREDEFINED_POLICY_FILE" ] ; then
         python $CONGRESS_DIR/scripts/preload-policies/output_policy_command.py \
             $CONGRESS_PREDEFINED_POLICY_FILE | while read CONGRESS_CMD
         do
@@ -194,7 +217,7 @@ function start_congress_service_and_check {
     local cfg_file
     local CFG_FILE_OPTIONS="--config-file $CONGRESS_CONF"
 
-    # Start the congress services in seperate processes
+    # Start the congress services in separate processes
     echo_summary "Installing congress services"
 
     if [ "$CONGRESS_MULTIPROCESS_DEPLOYMENT" == "False" ]; then
@@ -214,13 +237,9 @@ function start_congress_service_and_check {
     fi
 
     echo "Waiting for Congress to start..."
-    # FIXME(arosen): using curl right now to check if congress is alive once we implement version use check below.
-    if ! timeout $SERVICE_TIMEOUT sh -c "while ! curl --noproxy $CONGRESS_HOST http://$CONGRESS_HOST:$CONGRESS_PORT; do sleep 1; done"; then
+    if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q -O- http://$CONGRESS_HOST:$CONGRESS_PORT; do sleep 1; done"; then
         die $LINENO "Congress did not start"
     fi
-#    if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q -O- http://$CONGRESS_HOST:$CONGRESS_PORT; do sleep 1; done"; then
-#        die $LINENO "Congress did not start"
-#    fi
 
     # Expose encryption key to tempest test launched replica instances
     # WARNING: this setting deploys an insecure setup meant for gate-test only
@@ -233,6 +252,10 @@ function start_congress_service_and_check {
     # If needed in future, this script can read custom key location from
     # $CONGRESS_CONF and adjust accordingly
     if [ "$CONGRESS_EXPOSE_ENCRYPTION_KEY_FOR_TEST" == "True" ]; then
+        # Datasource service starts later than api service, so wait until datasource service fully started.
+        if ! timeout $SERVICE_TIMEOUT sh -c "while [ ! -f /etc/congress/keys/aes_key ]; do sleep 1; done"; then
+            die $LINENO "Unexpected error in key file creation"
+        fi
         chmod a+rx /etc/congress/keys
         chmod a+r /etc/congress/keys/aes_key
     fi
@@ -273,35 +296,98 @@ function _congress_setup_horizon {
     ln -fs $CONGRESSDASHBOARD_DIR/congress_dashboard/enabled/_60_policies.py $HORIZON_DIR/openstack_dashboard/local/enabled/
     ln -fs $CONGRESSDASHBOARD_DIR/congress_dashboard/enabled/_70_datasources.py $HORIZON_DIR/openstack_dashboard/local/enabled/
     ln -fs $CONGRESSDASHBOARD_DIR/congress_dashboard/enabled/_75_monitoring.py $HORIZON_DIR/openstack_dashboard/local/enabled/
+    ln -fs $CONGRESSDASHBOARD_DIR/congress_dashboard/enabled/_80_library.py $HORIZON_DIR/openstack_dashboard/local/enabled/
 
     # Restart Horizon
     restart_apache_server
 }
 
+function start_cfg_validator_agent {
+    echo "Launching congress config agent"
+    run_process congress-agent "$CONGRESS_BIN_DIR/congress-cfg-validator-agt --config-file $CONGRESS_AGT_CONF"
+}
+
+function configure_cfg_validator_agent {
+    if ! is_service_enabled congress; then
+        setup_develop $CONGRESS_DIR
+    fi
+    if [[ ! -d $CONGRESS_CONF_DIR ]]; then
+        sudo mkdir -p $CONGRESS_CONF_DIR
+    fi
+
+    sudo chown $STACK_USER $CONGRESS_CONF_DIR
+    touch $CONGRESS_AGT_CONF
+    sudo chown $STACK_USER $CONGRESS_AGT_CONF
+
+    iniset_rpc_backend cfg-validator $CONGRESS_AGT_CONF
+    iniset $CONGRESS_AGT_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
+
+    iniset $CONGRESS_AGT_CONF agent host $(hostname)
+    iniset $CONGRESS_AGT_CONF agent version pike
+
+    if is_service_enabled nova; then
+        VALIDATOR_SERVICES+="nova: { ${NOVA_CONF}:${NOVA_DIR}/etc/nova/nova-config-generator.conf },"
+    fi
+
+    if is_service_enabled neutron; then
+        VALIDATOR_SERVICES+="neutron: { ${NEUTRON_CONF}:${NEUTRON_DIR}/etc/oslo-config-generator/neutron.conf },"
+    fi
+
+    if is_service_enabled congress; then
+        VALIDATOR_SERVICES+="congress: { ${CONGRESS_CONF}:${CONGRESS_DIR}/etc/congress-config-generator.conf },"
+    fi
+
+    if [[ ! -z VALIDATOR_SERVICES ]]; then
+        iniset $CONGRESS_AGT_CONF agent services "${VALIDATOR_SERVICES%?}"
+    fi
+}
+
 # Main dispatcher
 #----------------
 
-if is_service_enabled congress; then
-    if [[ "$1" == "stack" && "$2" == "install" ]]; then
-        echo_summary "Installing Congress"
-        install_congress
-    elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
-        echo_summary "Configuring Congress"
-        configure_congress
+if is_service_enabled congress || is_service_enabled congress-agent; then
+    if [[ "$1" == "stack" ]]; then
+        if [[ "$2" == "install" ]]; then
+            echo_summary "Installing Congress"
+            install_congress
 
-        if is_service_enabled key; then
-            create_congress_accounts
+        elif [[ "$2" == "post-config" ]]; then
+            if is_service_enabled congress; then
+                echo_summary "Configuring Congress"
+                configure_congress
+
+                if is_service_enabled key; then
+                    create_congress_accounts
+                fi
+            fi
+
+            if is_service_enabled congress-agent; then
+                echo_summary "Configuring Validator agent"
+                configure_cfg_validator_agent
+            fi
+
+        elif [[ "$2" == "extra" ]]; then
+            if is_service_enabled congress; then
+                # Initialize Congress
+                init_congress
+
+                 # Start the congress API and Congress taskmgr components
+                echo_summary "Starting Congress"
+                start_congress_service_and_check
+                configure_congress_datasources
+                create_predefined_policy
+            fi
+
+            if is_service_enabled congress-agent; then
+                echo_summary "Starting Validator agent"
+                start_cfg_validator_agent
+            fi
+        elif [[ "$2" == "test-config" ]]; then
+            if is_service_enabled tempest; then
+                # Configure Tempest for Congress
+                _configure_tempest
+            fi
         fi
-
-    elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
-        # Initialize Congress
-        init_congress
-
-        # Start the congress API and Congress taskmgr components
-        echo_summary "Starting Congress"
-        start_congress_service_and_check
-        configure_congress_datasources
-        create_predefined_policy
     fi
 
     if [[ "$1" == "unstack" ]]; then
