@@ -24,12 +24,18 @@ sys.path.insert(0, os.path.abspath('./'))
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.todo',
-    'openstackdocstheme',
+    #'openstackdocstheme',
     #'sphinx.ext.intersphinx',
     'oslo_config.sphinxext',
     'oslo_config.sphinxconfiggen',
 ]
 
+# Don't use default openstack theme, for readthedocs
+on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
+
+if not on_rtd:
+    extensions.append('openstackdocstheme')
+
 # openstackdocstheme options
 repository_name = 'openstack/congress'
 bug_project = 'congress'
@@ -61,6 +67,8 @@ pygments_style = 'sphinx'
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['congress.']
 
+autodoc_mock_imports = ['congress.datalog.Python2', 'congress.datalog.Python3']
+
 # -- Options for HTML output --------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
@@ -89,8 +97,13 @@ latex_documents = [
 
 # -- Options for oslo_config.sphinxconfiggen ---------------------------------
 
-config_generator_config_file = '../../etc/congress-config-generator.conf'
-sample_config_basename = '_static/congress'
+config_generator_config_file = [
+    ('../../etc/congress-config-generator.conf',
+     '_static/congress'),
+    ('../../etc/congress-agent-config-generator.conf',
+     '_static/congress-agent')
+]
+
 
 [extensions]
 todo_include_todos=True
